import { ElementRef, Injector, OnInit } from '@angular/core';
import { Compare } from '@prizm-ui/helpers';
import { ControlValueAccessor } from '@angular/forms';
import { PolymorphContent } from '../../../directives/polymorph';
import { PrizmComboboxOptions } from './combobox.options';
import { PrizmNativeFocusableElement } from '../../../types';
import { Observable, Subject } from 'rxjs';
import { PrizmComboboxIdentityMatcher, PrizmComboboxStringify, PrizmComboboxValueContext, PrizmComboboxValueTransformer } from './combobox.model';
import { PrizmDropdownHostClasses, PrizmDropdownHostComponent, PrizmDropdownHostStyles } from '../dropdown-host';
import { PrizmOverlayOutsidePlacement } from '../../../modules/overlay';
import { PrizmInputNgControl } from '../../input/common/base/input-ng-control.class';
import { PrizmScrollbarVisibility } from '../../scrollbar';
import { PrizmComboboxDataListDirective } from './combobox-data-list.directive';
import { BooleanInput } from '@angular/cdk/coercion';
import { PrizmIconsFullRegistry } from '@prizm-ui/icons/core';
import * as i0 from "@angular/core";
export declare class PrizmComboboxComponent<T> extends PrizmInputNgControl<T | null> implements OnInit, ControlValueAccessor {
    private readonly options;
    readonly searchLabelTranslation$: Observable<string>;
    readonly focusableElement?: ElementRef<HTMLInputElement>;
    readonly dropdownHostElement?: PrizmDropdownHostComponent;
    customItemDataList?: PrizmComboboxDataListDirective;
    search: import("@angular/core").ModelSignal<string | null>;
    prizmHintDirection: PrizmOverlayOutsidePlacement;
    prizmHintCanShow: BooleanInput;
    items: import("@angular/core").ModelSignal<T[]>;
    updateSearchAfterItems: import("@angular/core").EffectRef;
    dropdownScroll: PrizmScrollbarVisibility;
    dropdownStyles: PrizmDropdownHostStyles;
    dropdownClasses: PrizmDropdownHostClasses;
    icon: PolymorphContent<import("./combobox.options").PrizmComboboxIconContext>;
    minDropdownHeight: number;
    maxDropdownHeight: number;
    placeholder: string;
    dropdownAutoReposition: boolean | undefined;
    dropdownWidth: string;
    transformer: PrizmComboboxValueTransformer<T>;
    emptyContent: PolymorphContent;
    readonly clickable = true;
    /**
     * need only clear function
     * */
    stringify: PrizmComboboxStringify<T>;
    identityMatcher: PrizmComboboxIdentityMatcher<T>;
    valueTemplate: PolymorphContent<PrizmComboboxValueContext<T>>;
    listItemTemplate: PolymorphContent<PrizmComboboxValueContext<T>>;
    readonly testId_ = "ui_combobox";
    readonly isNotNullish: typeof Compare.isNotNullish;
    readonly direction: PrizmOverlayOutsidePlacement;
    liveItems$: Observable<any[]>;
    readonly defaultIcon = "triangle-down";
    readonly nativeElementType = "combobox";
    readonly hasClearButton = true;
    readonly isNullish: typeof Compare.isNullish;
    protected userText: string | null;
    private searchValue;
    readonly focused$$: Subject<boolean>;
    readonly focused$: Observable<boolean>;
    readonly opened: import("@angular/core").WritableSignal<boolean>;
    readonly dropdownDisabled: import("@angular/core").Signal<boolean>;
    private readonly inputSelectOptionService;
    private readonly showDropdownOnEmpty;
    protected readonly iconsFullRegistry: PrizmIconsFullRegistry;
    constructor(options: PrizmComboboxOptions<T>, injector: Injector, searchLabelTranslation$: Observable<string>);
    private initSelectListener;
    ngOnInit(): void;
    get empty(): Observable<boolean>;
    get nativeFocusableElement(): PrizmNativeFocusableElement | null;
    get focused(): boolean;
    onClear(): void;
    clear(): void;
    select(item: T): void;
    onlySelect(item: T): void;
    updateValue(value: T | null): void;
    protected searchEmit(value: string): void;
    private updateFromSearch;
    getValueFromItems(value: T, items: T[]): T | undefined;
    getCurrentValue(value: T, items: T[]): string | Observable<string>;
    getFullObjectOfCurrent(value: T, items: T[]): T | null;
    stringifyForInner(i: T, outer?: boolean, label?: string | null, placeholder?: string): Observable<string>;
    protected onChangeModalVisible(visible: boolean): void;
    protected refreshLocalValue(value: T | null): void;
    protected changeParentFocusedClass(add: boolean): void;
    readonly printing: import("@angular/core").WritableSignal<KeyboardEvent | null>;
    private effectOnPrinting;
    private clearSearch;
    static ɵfac: i0.ɵɵFactoryDeclaration<PrizmComboboxComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PrizmComboboxComponent<any>, "prizm-combobox", ["prizmCombobox"], { "search": { "alias": "search"; "required": false; "isSignal": true; }; "prizmHintDirection": { "alias": "prizmHintDirection"; "required": false; }; "prizmHintCanShow": { "alias": "prizmHintCanShow"; "required": false; }; "items": { "alias": "items"; "required": true; "isSignal": true; }; "dropdownScroll": { "alias": "dropdownScroll"; "required": false; }; "dropdownStyles": { "alias": "dropdownStyles"; "required": false; }; "dropdownClasses": { "alias": "dropdownClasses"; "required": false; }; "icon": { "alias": "icon"; "required": false; }; "minDropdownHeight": { "alias": "minDropdownHeight"; "required": false; }; "maxDropdownHeight": { "alias": "maxDropdownHeight"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "dropdownAutoReposition": { "alias": "dropdownAutoReposition"; "required": false; }; "dropdownWidth": { "alias": "dropdownWidth"; "required": false; }; "transformer": { "alias": "transformer"; "required": false; }; "emptyContent": { "alias": "emptyContent"; "required": false; }; "stringify": { "alias": "stringify"; "required": false; }; "identityMatcher": { "alias": "identityMatcher"; "required": false; }; "valueTemplate": { "alias": "valueTemplate"; "required": false; }; "listItemTemplate": { "alias": "listItemTemplate"; "required": false; }; }, { "search": "searchChange"; "items": "itemsChange"; }, ["customItemDataList"], never, true, never>;
}
