import { AfterViewInit, ElementRef, Injector } from '@angular/core';
import { UntypedFormControl } from '@angular/forms';
import { PolymorphContent } from '../../../directives';
import { PrizmMultiSelectOptions } from './multi-select.options';
import { PrizmContextWithImplicit, PrizmNativeFocusableElement } from '../../../types';
import { PrizmInputNgControl } from '../../input';
import { BehaviorSubject, Observable, Subject } from 'rxjs';
import { PrizmDropdownHostClasses, PrizmDropdownHostComponent, PrizmDropdownHostStyles } from '../dropdown-host';
import { PrizmMultiSelectIdentityMatcher, PrizmMultiSelectItemStringifyFunc, PrizmMultiSelectItemWithChecked, PrizmMultiSelectSearchMatcher, PrizmMultiSelectValueTransformer } from './multi-select.model';
import { PrizmOverlayOutsidePlacement } from '../../../modules/overlay/models';
import { PrizmScrollbarVisibility } from '../../scrollbar';
import { PrizmIconsFullRegistry } from '@prizm-ui/icons/core';
import * as i0 from "@angular/core";
export declare class PrizmInputMultiSelectComponent<T> extends PrizmInputNgControl<T[]> implements AfterViewInit {
    readonly searchLabelTranslation$: Observable<string>;
    private readonly options;
    readonly nativeElementType = "multiselect";
    readonly hasClearButton = true;
    defaultLabel: string;
    readonly focusableElement?: ElementRef<HTMLElement>;
    readonly dropdownHostElement?: PrizmDropdownHostComponent;
    transformer: PrizmMultiSelectValueTransformer<T>;
    set items(data: T[]);
    get items(): T[];
    readonly clickable = true;
    dropdownScroll: PrizmScrollbarVisibility;
    dropdownStyles: PrizmDropdownHostStyles;
    dropdownClasses: PrizmDropdownHostClasses;
    icon: PolymorphContent<import("./multi-select.options").PrizmMultiSelectIconContext>;
    selectAllItem: T | null;
    searchable: boolean;
    isChipsDeletable: boolean;
    minDropdownHeight: number;
    dropdownWidth: string;
    maxDropdownHeight: number;
    dropdownAutoReposition: boolean | undefined;
    placeholder: string;
    searchMatcher: PrizmMultiSelectSearchMatcher<T>;
    emptyContent: PolymorphContent;
    /** need only clear function */
    stringify: PrizmMultiSelectItemStringifyFunc<T>;
    identityMatcher: PrizmMultiSelectIdentityMatcher<T>;
    valueTemplate: PolymorphContent<PrizmContextWithImplicit<PrizmMultiSelectItemWithChecked<T>>>;
    hidden: boolean;
    get button_layout_width(): 64 | 90;
    readonly testId_ = "ui-muilti-select";
    get display(): string;
    get inner(): boolean;
    get emptyChips(): boolean;
    get size(): string;
    readonly defaultIcon = "triangle-down";
    readonly direction: PrizmOverlayOutsidePlacement;
    readonly items$: BehaviorSubject<never[]>;
    readonly requiredInputControl: UntypedFormControl;
    readonly searchInputControl: UntypedFormControl;
    readonly chipsControl: UntypedFormControl;
    filteredItems$: Observable<PrizmMultiSelectItemWithChecked<T>[]>;
    selectedItems$: Observable<T[]>;
    readonly chipsSet: Map<string, T>;
    selectedItemsChips$: Observable<string[]>;
    fallbackValue: T[];
    filteredItems: PrizmMultiSelectItemWithChecked<T>[];
    private searchValue;
    readonly focused$$: Subject<boolean>;
    readonly focused$: Observable<boolean>;
    readonly opened$$: BehaviorSubject<boolean>;
    readonly opened$: Observable<boolean>;
    get empty(): boolean;
    protected readonly iconsFullRegistry: PrizmIconsFullRegistry;
    constructor(searchLabelTranslation$: Observable<string>, options: PrizmMultiSelectOptions<T>, injector: Injector);
    ngAfterViewInit(): void;
    ngOnInit(): void;
    private initSelectedItemsObservables;
    private initFilteredItemsObservables;
    get nativeFocusableElement(): PrizmNativeFocusableElement | null;
    get focused(): Observable<boolean>;
    clear(ev: MouseEvent): void;
    private isSelectAllItem;
    select(item: PrizmMultiSelectItemWithChecked<T>): void;
    removeChip(str: string): void;
    trackBy(index: number): number;
    changeParentFocusedClass(add: boolean): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<PrizmInputMultiSelectComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PrizmInputMultiSelectComponent<any>, "prizm-input-multi-select", never, { "transformer": { "alias": "transformer"; "required": false; }; "items": { "alias": "items"; "required": false; }; "dropdownScroll": { "alias": "dropdownScroll"; "required": false; }; "dropdownStyles": { "alias": "dropdownStyles"; "required": false; }; "dropdownClasses": { "alias": "dropdownClasses"; "required": false; }; "icon": { "alias": "icon"; "required": false; }; "selectAllItem": { "alias": "selectAllItem"; "required": false; }; "searchable": { "alias": "searchable"; "required": false; }; "isChipsDeletable": { "alias": "isChipsDeletable"; "required": false; }; "minDropdownHeight": { "alias": "minDropdownHeight"; "required": false; }; "dropdownWidth": { "alias": "dropdownWidth"; "required": false; }; "maxDropdownHeight": { "alias": "maxDropdownHeight"; "required": false; }; "dropdownAutoReposition": { "alias": "dropdownAutoReposition"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "searchMatcher": { "alias": "searchMatcher"; "required": false; }; "emptyContent": { "alias": "emptyContent"; "required": false; }; "stringify": { "alias": "stringify"; "required": false; }; "identityMatcher": { "alias": "identityMatcher"; "required": false; }; "valueTemplate": { "alias": "valueTemplate"; "required": false; }; }, {}, never, never, true, never>;
}
