import { AfterViewInit, ElementRef, EventEmitter, OnChanges, OnDestroy, Renderer2, SimpleChanges } from '@angular/core';
import { PrizmActionEvent, PrizmFileItemAction, PrizmFilesMap, PrizmFilesProgress, PrizmFileUploadOptions, PrizmFileValidationErrors } from './types';
import { Observable } from 'rxjs';
import { PrizmLanguageFileUpload } from '@prizm-ui/i18n';
import { PrizmAbstractTestId } from '@prizm-ui/core';
import { BooleanInput } from '@angular/cdk/coercion';
import { prizmIsTextOverflow } from '../../util';
import * as i0 from "@angular/core";
export declare class PrizmFileUploadComponent extends PrizmAbstractTestId implements OnChanges, AfterViewInit, OnDestroy {
    private renderer;
    readonly fileUpload$: Observable<PrizmLanguageFileUpload['fileUpload']>;
    dropzoneElementRef: ElementRef<HTMLDivElement>;
    accept: string;
    multiple: boolean;
    maxFileSize: number;
    set maxFilesCount(value: number);
    get disabled(): BooleanInput;
    set disabled(value: BooleanInput);
    set progress(progress: PrizmFilesProgress);
    set files(files: File[] | undefined);
    get files(): Array<File>;
    beforeFilesChange: EventEmitter<void>;
    afterFilesChange: EventEmitter<void>;
    filesChange: EventEmitter<File[]>;
    fileRemoved: EventEmitter<string>;
    fileAdded: EventEmitter<string>;
    filesValidationErrors: EventEmitter<{
        [filename: string]: PrizmFileValidationErrors;
    }>;
    filesCountError: EventEmitter<string[]>;
    retry: EventEmitter<File>;
    actionEvent: EventEmitter<PrizmActionEvent>;
    readonly testId_ = "ui_file_upload";
    readonly icon: {
        name: "file-empty";
        data: string;
    };
    readonly prizmIsTextOverflow: typeof prizmIsTextOverflow;
    calculatedMaxFilesCount: number;
    filesMap: PrizmFilesMap;
    options: PrizmFileUploadOptions;
    private readonly iconsFullRegistry;
    private listeners;
    private validationErrors;
    private _maxFilesCount;
    private _disabled;
    constructor(renderer: Renderer2, fileUpload$: Observable<PrizmLanguageFileUpload['fileUpload']>, customOptions: PrizmFileUploadOptions);
    ngOnChanges(changes: SimpleChanges): void;
    actions(filename: string): PrizmFileItemAction[];
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    onDrop(event: DragEvent): void;
    onFileInputChange(event: Event): void;
    actionHandler(event: string, data: string): void;
    getFileExtension(file: File): string;
    removeFile(filename: string, options?: {
        emitEvent: boolean;
    }): void;
    clearFiles(options?: {
        emitEvent: boolean;
    }): void;
    filesTrackBy(index: number, file: {
        key: string;
        value: any;
    }): string;
    retryUpload(filename: string): void;
    private dropzoneDragOverListener;
    private dropzoneDragLeaveListener;
    private selectFiles;
    private validate;
    private emitValidationErrors;
    private isImage;
    private isFileTypeValid;
    private getTypeClass;
    private isWildcard;
    static ɵfac: i0.ɵɵFactoryDeclaration<PrizmFileUploadComponent, [null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PrizmFileUploadComponent, "prizm-file-upload", never, { "accept": { "alias": "accept"; "required": false; }; "multiple": { "alias": "multiple"; "required": false; }; "maxFileSize": { "alias": "maxFileSize"; "required": false; }; "maxFilesCount": { "alias": "maxFilesCount"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "progress": { "alias": "progress"; "required": false; }; "files": { "alias": "files"; "required": false; }; }, { "beforeFilesChange": "beforeFilesChange"; "afterFilesChange": "afterFilesChange"; "filesChange": "filesChange"; "fileRemoved": "fileRemoved"; "fileAdded": "fileAdded"; "filesValidationErrors": "filesValidationErrors"; "filesCountError": "filesCountError"; "retry": "retry"; "actionEvent": "actionEvent"; }, never, ["*"], true, never>;
}
