import { AfterViewInit, ChangeDetectorRef, Injector, OnInit, TemplateRef } from '@angular/core';
import { BehaviorSubject, Observable } from 'rxjs';
import { PrizmDayRange } from '../../../@core/date-time/day-range';
import { PrizmDay } from '../../../@core/date-time/day';
import { PrizmBooleanHandler } from '../../../types/handler';
import { PrizmMarkerHandler } from '../../../types/marker-handler';
import { PrizmMonth } from '../../../@core/date-time/month';
import { PrizmDayRangePeriod } from '../../../@core/classes/day-range-period';
import { PrizmDayLike } from '../../../types/day-like';
import { PrizmDialogService } from '../../dialogs/dialog/dialog.service';
import { PrizmDateMode } from '../../../types/date-mode';
import { PrizmControlValueTransformer } from '../../../types/control-value-transformer';
import { PrizmInputNgControl } from '../common/base/input-ng-control.class';
import { PrizmDateTimeRange, PrizmTime } from '../../../@core';
import { PrizmInputZoneDirective } from '../../../directives/input-zone';
import { PrizmDateButton, PrizmTimeMode } from '../../../types';
import { PrizmDateTimeMinMax } from './model';
import { PrizmLanguageInputLayoutDateTimeRange } from '@prizm-ui/i18n';
import * as i0 from "@angular/core";
export declare class PrizmInputLayoutDateTimeRangeComponent extends PrizmInputNgControl<PrizmDateTimeRange | null> implements OnInit, AfterViewInit {
    private readonly dialogService;
    readonly dateFormat: PrizmDateMode;
    readonly dateSeparator: string;
    readonly dictionary$: Observable<PrizmLanguageInputLayoutDateTimeRange['inputLayoutDateTimeRange']>;
    readonly dateTexts$: Observable<Record<PrizmDateMode, string>>;
    hasClearButton: boolean;
    nativeElementType: string;
    readonly focusableElement?: PrizmInputZoneDirective;
    readonly footerFromTemplate?: TemplateRef<HTMLInputElement>;
    readonly footerToTemplate?: TemplateRef<HTMLInputElement>;
    disabledItemHandler: PrizmBooleanHandler<PrizmDay>;
    markerHandler: PrizmMarkerHandler;
    defaultViewedMonth: PrizmMonth;
    items: readonly PrizmDayRangePeriod[];
    placeholder: string;
    _min: PrizmDateTimeMinMax;
    set min(value: PrizmDateTimeMinMax | Date | string);
    _max: PrizmDateTimeMinMax;
    set max(value: PrizmDateTimeMinMax | Date | string);
    timeStrict: boolean;
    minLength: PrizmDayLike | null;
    maxLength: PrizmDayLike | null;
    open: boolean;
    timeMode: PrizmTimeMode;
    timeItems: readonly PrizmTime[];
    extraButtonInjector: Injector;
    readonly testId_ = "ui_input_date_time_range";
    testRange: PrizmDayRange;
    get interactive(): boolean;
    rightButtons$: BehaviorSubject<PrizmDateButton[]>;
    get calendarMinDay(): PrizmDay;
    get calendarMaxDay(): PrizmDay;
    readonly nativeValueTimeFrom$$: BehaviorSubject<string>;
    readonly nativeValueTimeTo$$: BehaviorSubject<string>;
    readonly nativeValueFrom$$: BehaviorSubject<string>;
    readonly nativeValueTo$$: BehaviorSubject<string>;
    readonly nativeValue$$: Observable<{
        timeRange: string[];
        dayRange: string[];
    }>;
    readonly hasNativeValue$: Observable<boolean>;
    readonly empty$: Observable<boolean>;
    get empty(): Observable<boolean>;
    private readonly iconsFullRegistry;
    constructor(changeDetectorRef: ChangeDetectorRef, injector: Injector, dialogService: PrizmDialogService, dateFormat: PrizmDateMode, dateSeparator: string, dictionary$: Observable<PrizmLanguageInputLayoutDateTimeRange['inputLayoutDateTimeRange']>, dateTexts$: Observable<Record<PrizmDateMode, string>>, valueTransformer: PrizmControlValueTransformer<PrizmDateTimeRange | null> | null);
    get focused(): Observable<boolean>;
    get canOpen(): boolean;
    closeOnOutsideClick: boolean;
    get computedTimeMask(): string;
    get computedDateMask(): string;
    get fromValue(): string;
    get fromTimeValue(): string;
    get toValue(): string;
    get toTimeValue(): string;
    onOpenChange(open: boolean): void;
    ngAfterViewInit(): void;
    ngOnInit(): void;
    onDateValueChange(value: string, isFormValue: boolean): void;
    onTimeValueChange(value: string, isFormValue: boolean): void;
    onRangeChange(range: PrizmDayRange | null): void;
    private completeDateIfAreNotPending;
    private updateWithCorrectDateAndTime;
    private timeLimit;
    private getDayFromMinMax;
    private getTimeFromMinMax;
    private dayLimit;
    private toggle;
    private focusInput;
    clear(ev: MouseEvent): void;
    updateTimeTo(value: PrizmTime): void;
    updateTimeFrom(value: PrizmTime): void;
    referFocusToMain(referFocus?: boolean): void;
    private timeToString;
    static ɵfac: i0.ɵɵFactoryDeclaration<PrizmInputLayoutDateTimeRangeComponent, [null, null, null, { optional: true; }, null, null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PrizmInputLayoutDateTimeRangeComponent, "prizm-input-layout-date-time-range", never, { "disabledItemHandler": { "alias": "disabledItemHandler"; "required": false; }; "markerHandler": { "alias": "markerHandler"; "required": false; }; "defaultViewedMonth": { "alias": "defaultViewedMonth"; "required": false; }; "items": { "alias": "items"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "min": { "alias": "min"; "required": false; }; "max": { "alias": "max"; "required": false; }; "timeStrict": { "alias": "timeStrict"; "required": false; }; "minLength": { "alias": "minLength"; "required": false; }; "maxLength": { "alias": "maxLength"; "required": false; }; "timeMode": { "alias": "timeMode"; "required": false; }; "timeItems": { "alias": "timeItems"; "required": false; }; "extraButtonInjector": { "alias": "extraButtonInjector"; "required": false; }; }, {}, ["footerFromTemplate", "footerToTemplate"], never, true, never>;
}
